==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_CommandEvent.h <==
//----------------------------------------------------------------------------
// wxCommandEvent
// extracted from cmdevent.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_COMMANDEVENT_H__
#define __CLASS_WX_COMMANDEVENT_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxCommandEvent
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_CommandEvent);

//----------------------------------------------------------------------------
// Object declaration for wxCommandEvent
//----------------------------------------------------------------------------
class Object_wx_CommandEvent : public Object_wx_Event {
public:
	Gura_DeclareObjectAccessor(wx_CommandEvent)
public:
	inline Object_wx_CommandEvent(wxCommandEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Event(Gura_UserClass(wx_CommandEvent), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_CommandEvent(Class *pClass, wxCommandEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Event(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_CommandEvent();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxCommandEvent *GetEntity() {
		return dynamic_cast<wxCommandEvent *>(_pEntity);
	}
	inline wxCommandEvent *ReleaseEntity() {
		wxCommandEvent *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxCommandEvent");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_CommandEvent.h <==
//----------------------------------------------------------------------------
// wxCommandEvent
// extracted from cmdevent.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_COMMANDEVENT_H__
#define __CLASS_WX_COMMANDEVENT_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxCommandEvent
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_CommandEvent);

//----------------------------------------------------------------------------
// Object declaration for wxCommandEvent
//----------------------------------------------------------------------------
class Object_wx_CommandEvent : public Object_wx_Event {
public:
	Gura_DeclareObjectAccessor(wx_CommandEvent)
public:
	inline Object_wx_CommandEvent(wxCommandEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Event(Gura_UserClass(wx_CommandEvent), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_CommandEvent(Class *pClass, wxCommandEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Event(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_CommandEvent();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxCommandEvent *GetEntity() {
		return dynamic_cast<wxCommandEvent *>(_pEntity);
	}
	inline wxCommandEvent *ReleaseEntity() {
		wxCommandEvent *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxCommandEvent");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
